from loguru import logger
import telegram
from functools import wraps

def telegram_logger(token, chat_ids):
    def decorator(func):
        bot = telegram.Bot(token=token)

        @wraps(func)
        def wrapper(*args, **kwargs):
            try:
                result = func(*args, **kwargs)
                logger.info(result)
                for chat_id in chat_ids:
                    bot.send_message(chat_id=chat_id, text=str(result))
                return result
            except Exception as e:
                logger.exception(e)
                for chat_id in chat_ids:
                    bot.send_message(chat_id=chat_id, text=str(e))
                raise

        return wrapper

    return decorator


from logging import Logger
import logging


class LoggerHandler(logging.Handler):
    def __init__(self, api_key, chat_id, log_level):
        super().__init__()
        self.logger = Logger(api_key, chat_id, log_level)

    def emit(self, record):
        log_entry = self.format(record)
        if record.levelno >= self.logger.log_level:
            if record.levelno == logging.DEBUG:
                self.logger.debug(log_entry)
            elif record.levelno == logging.INFO:
                self.logger.info(log_entry)
            elif record.levelno == logging.WARNING:
                self.logger.warning(log_entry)
            elif record.levelno == logging.ERROR:
                self.logger.error(log_entry)
            elif record.levelno == logging.CRITICAL:
                self.logger.error(log_entry)



from setuptools import setup, find_packages

setup(
    name='logger-telegram-v',
    version='0.1.0',
    description='A library for sending logs to Telegram',
    author='Vatche Thorossian',
    author_email='vatche.thorossian@gmail.com',
    url='https://github.com/yourusername/logger-telegram-v',
    packages=find_packages(),
    install_requires=['loguru', 'python-telegram-bot'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
)



class Logger:
    def __init__(self, api_key, chat_id, log_level):
        self.api_key = api_key
        self.chat_id = chat_id
        self.log_level = log_level

    def debug(self, message):
        pass

    def info(self, message):
        pass

    def success(self, message):
        pass

    def warning(self, message):
        pass

    def error(self, message):
        pass
